@@ -1,7 +1,6 @@
 require 'digest/md5'
 
 Puppet::Type.newtype(:ini_subsetting) do
-
   ensurable do
     defaultvalues
     defaultto :present
@@ -16,18 +15,18 @@ Puppet::Type.newtype(:ini_subsetting) do
     when :md5, 'md5'
       :md5
     else
-      fail('expected a boolean value or :md5')
+      raise('expected a boolean value or :md5')
     end
   end
 
-  newparam(:name, :namevar => true) do
+  newparam(:name, namevar: true) do
     desc 'An arbitrary name used as the identity of the resource.'
   end
 
   newparam(:section) do
-    desc 'The name of the section in the ini file in which the setting should be defined.' +
-      'If not provided, defaults to global, top of file, sections.'
-    defaultto("")
+    desc 'The name of the section in the ini file in which the setting should be defined.' \
+         'If not provided, defaults to global, top of file, sections.'
+    defaultto('')
   end
 
   newparam(:setting) do
@@ -40,7 +39,7 @@ Puppet::Type.newtype(:ini_subsetting) do
 
   newparam(:subsetting_separator) do
     desc 'The separator string between subsettings. Defaults to " "'
-    defaultto(" ")
+    defaultto(' ')
   end
 
   newparam(:subsetting_key_val_separator) do
@@ -51,7 +50,7 @@ Puppet::Type.newtype(:ini_subsetting) do
   newparam(:path) do
     desc 'The ini file Puppet will ensure contains the specified setting.'
     validate do |value|
-      unless (Puppet.features.posix? and value =~ /^\//) or (Puppet.features.microsoft_windows? and (value =~ /^.:\// or value =~ /^\/\/[^\/]+\/[^\/]+/))
+      unless (Puppet.features.posix? && value =~ %r{^\/}) || (Puppet.features.microsoft_windows? && (value =~ %r{^.:\/} || value =~ %r{^\/\/[^\/]+\/[^\/]+}))
         raise(Puppet::Error, "File paths must be fully qualified, not '#{value}'")
       end
     end
@@ -68,20 +67,20 @@ Puppet::Type.newtype(:ini_subsetting) do
   end
 
   newparam(:key_val_separator) do
-    desc 'The separator string to use between each setting name and value. ' +
-        'Defaults to " = ", but you could use this to override e.g. ": ", or' +
-        'whether or not the separator should include whitespace.'
-    defaultto(" = ")
+    desc 'The separator string to use between each setting name and value. ' \
+         'Defaults to " = ", but you could use this to override e.g. ": ", or' \
+         'whether or not the separator should include whitespace.'
+    defaultto(' = ')
   end
 
   newparam(:quote_char) do
     desc 'The character used to quote the entire value of the setting. ' +
-        %q{Valid values are '', '"' and "'". Defaults to ''.}
+         %q(Valid values are '', '"' and "'". Defaults to ''.)
     defaultto('')
 
     validate do |value|
-      unless value =~ /^["']?$/
-        raise Puppet::Error, %q{:quote_char valid values are '', '"' and "'"}
+      unless value =~ %r{^["']?$}
+        raise Puppet::Error, %q(:quote_char valid values are '', '"' and "'")
       end
     end
   end
@@ -96,33 +95,29 @@ Puppet::Type.newtype(:ini_subsetting) do
     desc 'The value of the subsetting to be defined.'
 
     def should_to_s(newvalue)
-      if (@resource[:show_diff] == :true && Puppet[:show_diff]) then
-        return newvalue
-      elsif (@resource[:show_diff] == :md5 && Puppet[:show_diff]) then
-        return '{md5}' + Digest::MD5.hexdigest(newvalue.to_s)
+      if @resource[:show_diff] == :true && Puppet[:show_diff]
+        newvalue
+      elsif @resource[:show_diff] == :md5 && Puppet[:show_diff]
+        '{md5}' + Digest::MD5.hexdigest(newvalue.to_s)
       else
-        return '[redacted sensitive information]'
+        '[redacted sensitive information]'
       end
     end
 
-    def is_to_s(value)
-      should_to_s(value)
-    end
-
-    def is_to_s(value)
+    def is_to_s(value) # rubocop:disable Style/PredicateName : Changing breaks the code (./.bundle/gems/gems/puppet-5.3.3-universal-darwin/lib/puppet/parameter.rb:525:in `to_s')
       should_to_s(value)
     end
   end
 
   newparam(:insert_type) do
     desc <<-eof
-Where the new subsetting item should be inserted?
+      Where the new subsetting item should be inserted?
 
-* :start  - insert at the beginning of the line.
-* :end    - insert at the end of the line (default).
-* :before - insert before the specified element if possible.
-* :after  - insert after the specified element if possible.
-* :index  - insert at the specified index number.
+      * :start  - insert at the beginning of the line.
+      * :end    - insert at the end of the line (default).
+      * :before - insert before the specified element if possible.
+      * :after  - insert after the specified element if possible.
+      * :index  - insert at the specified index number.
     eof
 
     newvalues(:start, :end, :before, :after, :index)
@@ -132,5 +127,4 @@ Where the new subsetting item should be inserted?
   newparam(:insert_value) do
     desc 'The value for the insert types which require one.'
   end
-
 end
